// slideshow.js
// Liam Quin, September 2014
// Does not rely on jQuery
//
// Bind keys
// arrow keys to go forward and back a slide
// "c" or "t" to go to table of contents
// 0 .. 9 to change text size
//
// see http://www.quirksmode.org/js/events/keys.html or maybe
// http://stackoverflow.com/questions/1402698/binding-arrow-keys-in-js-jquery
// for more on key binding

document.onkeydown = function(event) {
    event = event || window.event;

    var key, target;

    if (window.event) {
	key = window.event.keyCode;
	target = window.event.srcElement;
    } else if (event.which) {
	key = event.which;
	target = event.target;
    } else {
	return true; // unexpected
    }

    if (!key) {
	return true; // e.g. the alt key by itself
    }

    if (event.ctrlKey || event.altKey || event.metaKey) {
	return true;
    }

    var getrel = function(relvalue) {
	// find link with rel="next" or whatever
	var links = document.getElementsByTagName("link");

	for (var i = 0; i < links.length; i++) {
	    if (links[i].rel == relvalue) {
		return '' + links[i].href;
	    }
	}
	return null;
    }

    switch(key) {
	case 37: // left
	    {
		var prev = getrel("previous");
		if (prev) {
		    document.location = prev; // go there
		}
	    }
	    break;

	// case 38: // up
	    // document.location = "contents.html";
	    // this is a bad idea because of screen scrolling
	    // break;

	// case 32: // space
	case 39: // right
	    {
		var prev = getrel("next");
		if (prev) {
		    document.location = prev; // go there
		}
	    }
	    break;

	case 48: /* 0 */ { mtZoom("10pt"); } break;
	case 49: /* 1 */ { mtZoom("12pt"); } break;
	case 50: /* 2 */ { mtZoom("14pt"); } break;
	case 51: /* 3 */ { mtZoom("16pt"); } break;
	case 52: /* 4 */ { mtZoom("18pt"); } break;
	case 53: /* 5 */ { mtZoom("20pt"); } break;
	case 54: /* 6 */ { mtZoom("22pt"); } break;
	case 55: /* 7 */ { mtZoom("24pt"); } break;
	case 56: /* 8 */ { mtZoom("26pt"); } break;
	case 57: /* 9 */ { mtZoom("28pt"); } break;

	case 67: // c
	    {
		document.location = "contents.html";
	    }
	    break;

	case 68: /* d */
	    { mtUnZoom("12pt"); } break; /* the default */

	case 71: /* g - go to marked page */
	    { mtGotoMark(); }
	    break;

	case 77: /* m  mark page */
	    { mtMarkPage(); }
	    break;

	case 84: /* t - toggle whether tables are scaled */
	     {
		 toggleTableZoom();
		 break;
	     }

	default: return true;
    }
    event.preventDefault(); // e.g.  don't try and scroll horizontally for arrow keys
    return true;
}

var prefix = "MulberryJuice-";
var MulberryTableZoom = "yes";

function mtZoom(zlevel)
{
    var body = document.getElementsByTagName("body");
    if (body) {
	body[0].style.fontSize = zlevel;
	localStorage.setItem(prefix + "zoomLevel", zlevel);
	localStorage.setItem(prefix + "tableZoom", MulberryTableZoom);
	if (MulberryTableZoom === "yes") {
	    ZoomTables(zlevel);
	}
    }
}

function mtGetZoom()
{
    var result = localStorage.getItem(prefix + "zoomLevel");
    if (result) {
	return result;
    } else {
	return "100%";
    }
}

var mtRememberedPage;
function mtUnZoom(zlevel)
{
    var body = document.getElementsByTagName("body");
    if (body) {
	body[0].style.fontSize = zlevel;
	localStorage.removeItem(prefix + "zoomLevel");
	localStorage.removeItem(prefix + "tableZoom");
	localStorage.removeItem(prefix + "mark");
	mtRememberedPage = false;
	MulberryTableZoom = "yes";
	ZoomTables(zlevel);
    }
}

function initZoom()
{
    var z = mtGetZoom();

    if (z) {
	mtZoom(z);
    }

    mtUpdateHelpText();
}

/* Cross-browser DOM code to find elements by class; there is
 * now querySelectorAll() and getElementsByClassName() but not
 * in IE8 and older
 */

function findNodesByClass(matchClass) {
    var elems = document.getElementsByTagName('*');
    var theNodes = [];
    var i;
    var n = elems.length;
    for (i = 0; i < n; i++) {
        if ((' ' + elems[i].className + ' ').indexOf(' ' + matchClass + ' ')
                > -1) {
	    theNodes.push(elems[i]);
        }
    }
    return theNodes;
}

function toggleTableZoom()
{
    if (MulberryTableZoom === "yes") {
	MulberryTableZoom = "no";
	ZoomTables("12pt");
    } else {
	/* was no */
	MulberryTableZoom = "yes";
	var z = mtGetZoom();
	if (z) {
	    mtZoom(z);
	}
    }
    mtUpdateHelpText();
}

function ZoomTables(zlevel)
{
    var theTables = findNodesByClass("mt-table");
    var n = theTables.length;
    for (var i = 0; i < n; i++) {
	theTables[i].style.fontSize = zlevel;
    }
}

function mtMarkPage()
{
    var here = document.location;
    if (here) {
	localStorage.setItem(prefix + "mark", here);
	var theSlide = findNodesByClass("headerNumber");
	if (theSlide && theSlide[0] && theSlide[0].textContent) {
	    mtRememberedPage = theSlide[0].textContent;
	} else {
	    /* this is usually the cover page */
	    var titles = document.getElementsByTagName("title");
	    var i;

	    mtRememberedPage = "title unavailable";
	    for (i = 0; i < titles.length; i++) {
		if (titles[i].textContent) {
		    mtRememberedPage = "" + titles[i].textContent;
		}
	    }
	}
	localStorage.setItem(prefix + "mark-title", mtRememberedPage);
	mtUpdateHelpText();
    }
}

function mtGotoMark()
{
    var there = localStorage.getItem(prefix + "mark");

    if (there) {
	document.location = there;
    }
}

function mtUpdateHelpText()
{
    var h = findNodesByClass("helpButton");

    if (!h) {
	return;
    }

    var hn = h.length;

    var zoom = "(now on)";
    if (MulberryTableZoom === "no") {
	zoom = "(now off)";
    }

    var mark = ";g - go to marked page (none)";

    var there = localStorage.getItem(prefix + "mark-title");
    if (there) {
	mark = "; g - go to marked page (" + there + ")";
	mtRememberedPage = there;
    }

    for (var i = 0; i < hn; i++) {
	h[i].title = "next slide; keys: c contents, 0-9 size, d default size, arrows to move;\nt table mode " + zoom + "; m mark page" + mark;
    }
}



/* $Id: slideshow.js,v 1.2 2015/01/04 04:13:48 lee Exp $ */
